@@ -3,8 +3,9 @@ Main interface for workmail service.
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.workmail import (
+    from mypy_boto3_workmail import (
         Client,
         ListAliasesPaginator,
         ListGroupMembersPaginator,
@@ -15,7 +16,7 @@ Usage::
         ListResourcesPaginator,
         ListUsersPaginator,
         WorkMailClient,
-        )
+    )
 
     session = boto3.Session()
 
@@ -30,6 +31,7 @@ Usage::
     list_resource_delegates_paginator: ListResourceDelegatesPaginator = client.get_paginator("list_resource_delegates")
     list_resources_paginator: ListResourcesPaginator = client.get_paginator("list_resources")
     list_users_paginator: ListUsersPaginator = client.get_paginator("list_users")
+    ```
 """
 from mypy_boto3_workmail.client import WorkMailClient as Client, WorkMailClient
 from mypy_boto3_workmail.paginator import (
