@@ -3,9 +3,11 @@ Main interface for workmail service type definitions.
 
 Usage::
 
-    from mypy_boto3.workmail.type_defs import AccessControlRuleTypeDef
+    ```python
+    from mypy_boto3_workmail.type_defs import AccessControlRuleTypeDef
 
     data: AccessControlRuleTypeDef = {...}
+    ```
 """
 from datetime import datetime
 import sys
